==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/Event/PeopleEventType.php <==
<?php
namespace Claromentis\People\Event;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array();




class PeopleEventType
{
    const PRE_ADD_USER = 'people.pre_add_user';
    const ADD_USER = 'people.add_user';
    const PRE_UPDATE_USER = 'people.pre_update_user';
    const UPDATE_USER = 'people.update_user';
    const SET_USER_GROUPS = 'people.admin.set_user_groups';
    const SET_USER_ROLES = 'people.admin.set_user_roles';
    const SET_USER_MANAGER = 'people.admin.set_user_manager';
    const SET_USER_SUBORDINATES = 'people.admin.set_user_subordinates';
    const PRE_DELETE_USER = 'people.pre_delete_user';
    const DELETE_USER = 'people.delete_user';
    const ADD_SKILL = 'people.admin.add_skill';
    const UPDATE_SKILL = 'people.admin.update_skill';
    const DELETE_SKILL = 'people.admin.delete_skill';
    const ADD_ROLE = 'people.admin.add_role';
    const UPDATE_ROLE = 'people.admin.update_role';
    const DELETE_ROLE = 'people.admin.delete_role';
    const SET_ROLE_USERS = 'people.admin.set_role_users';
    const ADD_GROUP = 'people.admin.add_group';
    const UPDATE_GROUP = 'people.admin.update_group';
    const DELETE_GROUP = 'people.admin.delete_group';
    const SET_GROUP_USERS = 'people.admin.set_group_users';
    const ADD_EXTRANET = 'people.admin.add_extranet';
    const UPDATE_EXTRANET = 'people.admin.update_extranet';
    const SET_EXTRANET_USERS = 'people.admin.update_extranet_users';
    const DELETE_EXTRANET = 'people.admin.delete_extranet';
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/Event/PeopleEventType.php <==
<?php
namespace Claromentis\People\Event;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array();




class PeopleEventType
{
    const PRE_ADD_USER = 'people.pre_add_user';
    const ADD_USER = 'people.add_user';
    const PRE_UPDATE_USER = 'people.pre_update_user';
    const UPDATE_USER = 'people.update_user';
    const SET_USER_GROUPS = 'people.admin.set_user_groups';
    const SET_USER_ROLES = 'people.admin.set_user_roles';
    const SET_USER_MANAGER = 'people.admin.set_user_manager';
    const SET_USER_SUBORDINATES = 'people.admin.set_user_subordinates';
    const PRE_DELETE_USER = 'people.pre_delete_user';
    const DELETE_USER = 'people.delete_user';
    const ADD_SKILL = 'people.admin.add_skill';
    const UPDATE_SKILL = 'people.admin.update_skill';
    const DELETE_SKILL = 'people.admin.delete_skill';
    const ADD_ROLE = 'people.admin.add_role';
    const UPDATE_ROLE = 'people.admin.update_role';
    const DELETE_ROLE = 'people.admin.delete_role';
    const SET_ROLE_USERS = 'people.admin.set_role_users';
    const ADD_GROUP = 'people.admin.add_group';
    const UPDATE_GROUP = 'people.admin.update_group';
    const DELETE_GROUP = 'people.admin.delete_group';
    const SET_GROUP_USERS = 'people.admin.set_group_users';
    const ADD_EXTRANET = 'people.admin.add_extranet';
    const UPDATE_EXTRANET = 'people.admin.update_extranet';
    const SET_EXTRANET_USERS = 'people.admin.update_extranet_users';
    const DELETE_EXTRANET = 'people.admin.delete_extranet';
}
